# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_age_distribution_data import ReportingAgeDistributionData
from neurograph.v1.models.reporting_demographics_meta import ReportingDemographicsMeta
from neurograph.v1.models.reporting_gender_split_data import ReportingGenderSplitData
from neurograph.v1.models.reporting_geographic_distribution_data import ReportingGeographicDistributionData
from neurograph.v1.models.reporting_income_bands_data import ReportingIncomeBandsData
from typing import Optional, Set
from typing_extensions import Self

class ReportingPersonaDemographicsResponse(BaseModel):
    """
    ReportingPersonaDemographicsResponse
    """ # noqa: E501
    age_distribution: Optional[ReportingAgeDistributionData] = None
    cached: Optional[StrictBool] = None
    error: Optional[StrictStr] = None
    gender_split: Optional[ReportingGenderSplitData] = None
    geographic_distribution: Optional[ReportingGeographicDistributionData] = None
    income_bands: Optional[ReportingIncomeBandsData] = None
    meta: Optional[ReportingDemographicsMeta] = None
    query_time_ms: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["age_distribution", "cached", "error", "gender_split", "geographic_distribution", "income_bands", "meta", "query_time_ms"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingPersonaDemographicsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of age_distribution
        if self.age_distribution:
            _dict['age_distribution'] = self.age_distribution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of gender_split
        if self.gender_split:
            _dict['gender_split'] = self.gender_split.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geographic_distribution
        if self.geographic_distribution:
            _dict['geographic_distribution'] = self.geographic_distribution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of income_bands
        if self.income_bands:
            _dict['income_bands'] = self.income_bands.to_dict()
        # override the default output from pydantic by calling `to_dict()` of meta
        if self.meta:
            _dict['meta'] = self.meta.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingPersonaDemographicsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "age_distribution": ReportingAgeDistributionData.from_dict(obj["age_distribution"]) if obj.get("age_distribution") is not None else None,
            "cached": obj.get("cached"),
            "error": obj.get("error"),
            "gender_split": ReportingGenderSplitData.from_dict(obj["gender_split"]) if obj.get("gender_split") is not None else None,
            "geographic_distribution": ReportingGeographicDistributionData.from_dict(obj["geographic_distribution"]) if obj.get("geographic_distribution") is not None else None,
            "income_bands": ReportingIncomeBandsData.from_dict(obj["income_bands"]) if obj.get("income_bands") is not None else None,
            "meta": ReportingDemographicsMeta.from_dict(obj["meta"]) if obj.get("meta") is not None else None,
            "query_time_ms": obj.get("query_time_ms")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OrganizationsGammaCardSettings(BaseModel):
    """
    OrganizationsGammaCardSettings
    """ # noqa: E501
    accent_image_shape: Optional[StrictInt] = Field(default=None, description="0-7 (various shapes)")
    card_border: Optional[StrictInt] = Field(default=None, description="0-3 scale (none, thin, medium, thick)")
    card_border_color: Optional[StrictStr] = None
    card_shadow: Optional[StrictInt] = Field(default=None, description="0-2 scale (none, subtle, strong)")
    card_transparency: Optional[StrictInt] = Field(default=None, description="0-2 scale (solid, semi, transparent)")
    roundness: Optional[StrictInt] = Field(default=None, description="0-4 scale (0=square, 4=most rounded)")
    __properties: ClassVar[List[str]] = ["accent_image_shape", "card_border", "card_border_color", "card_shadow", "card_transparency", "roundness"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationsGammaCardSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationsGammaCardSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accent_image_shape": obj.get("accent_image_shape"),
            "card_border": obj.get("card_border"),
            "card_border_color": obj.get("card_border_color"),
            "card_shadow": obj.get("card_shadow"),
            "card_transparency": obj.get("card_transparency"),
            "roundness": obj.get("roundness")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OrganizationsGammaThemeRequest(BaseModel):
    """
    OrganizationsGammaThemeRequest
    """ # noqa: E501
    accent_color: Optional[StrictStr] = None
    background_color: Optional[StrictStr] = None
    border_color: Optional[StrictStr] = None
    brand_personality: Optional[StrictStr] = None
    brand_reasoning: Optional[StrictStr] = Field(default=None, description="Brand analysis context from AI branding generation")
    brand_style: Optional[StrictStr] = None
    industry: Optional[StrictStr] = Field(default=None, description="Optional context")
    primary_color: Optional[StrictStr] = Field(default=None, description="Core brand colors")
    secondary_color: Optional[StrictStr] = None
    source_url: Optional[StrictStr] = None
    surface_color: Optional[StrictStr] = None
    target_audience: Optional[StrictStr] = None
    text_color: Optional[StrictStr] = None
    text_secondary_color: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["accent_color", "background_color", "border_color", "brand_personality", "brand_reasoning", "brand_style", "industry", "primary_color", "secondary_color", "source_url", "surface_color", "target_audience", "text_color", "text_secondary_color"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrganizationsGammaThemeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrganizationsGammaThemeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accent_color": obj.get("accent_color"),
            "background_color": obj.get("background_color"),
            "border_color": obj.get("border_color"),
            "brand_personality": obj.get("brand_personality"),
            "brand_reasoning": obj.get("brand_reasoning"),
            "brand_style": obj.get("brand_style"),
            "industry": obj.get("industry"),
            "primary_color": obj.get("primary_color"),
            "secondary_color": obj.get("secondary_color"),
            "source_url": obj.get("source_url"),
            "surface_color": obj.get("surface_color"),
            "target_audience": obj.get("target_audience"),
            "text_color": obj.get("text_color"),
            "text_secondary_color": obj.get("text_secondary_color")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reporting_age_breakdown_row import ReportingAgeBreakdownRow
from neurograph.v1.models.reporting_summary_kpis import ReportingSummaryKPIs
from neurograph.v1.models.reporting_traffic_pipeline_day import ReportingTrafficPipelineDay
from neurograph.v1.models.reporting_traffic_trend_day import ReportingTrafficTrendDay
from typing import Optional, Set
from typing_extensions import Self

class ReportingCustomerInsightsResponse(BaseModel):
    """
    ReportingCustomerInsightsResponse
    """ # noqa: E501
    age_breakdown: Optional[List[ReportingAgeBreakdownRow]] = None
    cached: Optional[StrictBool] = None
    error: Optional[StrictStr] = None
    summary: Optional[ReportingSummaryKPIs] = None
    traffic_trend: Optional[List[ReportingTrafficTrendDay]] = None
    traffic_value_pipeline: Optional[List[ReportingTrafficPipelineDay]] = None
    __properties: ClassVar[List[str]] = ["age_breakdown", "cached", "error", "summary", "traffic_trend", "traffic_value_pipeline"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingCustomerInsightsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in age_breakdown (list)
        _items = []
        if self.age_breakdown:
            for _item_age_breakdown in self.age_breakdown:
                if _item_age_breakdown:
                    _items.append(_item_age_breakdown.to_dict())
            _dict['age_breakdown'] = _items
        # override the default output from pydantic by calling `to_dict()` of summary
        if self.summary:
            _dict['summary'] = self.summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in traffic_trend (list)
        _items = []
        if self.traffic_trend:
            for _item_traffic_trend in self.traffic_trend:
                if _item_traffic_trend:
                    _items.append(_item_traffic_trend.to_dict())
            _dict['traffic_trend'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in traffic_value_pipeline (list)
        _items = []
        if self.traffic_value_pipeline:
            for _item_traffic_value_pipeline in self.traffic_value_pipeline:
                if _item_traffic_value_pipeline:
                    _items.append(_item_traffic_value_pipeline.to_dict())
            _dict['traffic_value_pipeline'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingCustomerInsightsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "age_breakdown": [ReportingAgeBreakdownRow.from_dict(_item) for _item in obj["age_breakdown"]] if obj.get("age_breakdown") is not None else None,
            "cached": obj.get("cached"),
            "error": obj.get("error"),
            "summary": ReportingSummaryKPIs.from_dict(obj["summary"]) if obj.get("summary") is not None else None,
            "traffic_trend": [ReportingTrafficTrendDay.from_dict(_item) for _item in obj["traffic_trend"]] if obj.get("traffic_trend") is not None else None,
            "traffic_value_pipeline": [ReportingTrafficPipelineDay.from_dict(_item) for _item in obj["traffic_value_pipeline"]] if obj.get("traffic_value_pipeline") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_daily_client_pixel_metrics import PixelDailyClientPixelMetrics

class TestPixelDailyClientPixelMetrics(unittest.TestCase):
    """PixelDailyClientPixelMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelDailyClientPixelMetrics:
        """Test PixelDailyClientPixelMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelDailyClientPixelMetrics`
        """
        model = PixelDailyClientPixelMetrics()
        if include_optional:
            return PixelDailyClientPixelMetrics(
                avg_match_confidence = 1.337,
                avg_session_duration = 1.337,
                daily_cost = 1.337,
                var_date = '',
                enriched_visitors = 56,
                enrichment_rate_pct = 1.337,
                match_rate_pct = 1.337,
                matched_hems = 56,
                temporal_matches = 56,
                total_pageviews = 56,
                total_sessions = 56,
                unique_visitors = 56,
                vendor_matches = 56
            )
        else:
            return PixelDailyClientPixelMetrics(
        )
        """

    def testPixelDailyClientPixelMetrics(self):
        """Test PixelDailyClientPixelMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_product_performance_data import ReportingProductPerformanceData

class TestReportingProductPerformanceData(unittest.TestCase):
    """ReportingProductPerformanceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingProductPerformanceData:
        """Test ReportingProductPerformanceData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingProductPerformanceData`
        """
        model = ReportingProductPerformanceData()
        if include_optional:
            return ReportingProductPerformanceData(
                products = [
                    neurograph.v1.models.reporting/product_performance_row.reporting.ProductPerformanceRow(
                        affinity_score = 1.337, 
                        affinity_tier = '', 
                        avg_spend = 1.337, 
                        conversion_rate = 1.337, 
                        engagement_score = 1.337, 
                        product_handle = '', 
                        product_name = '', 
                        product_type = '', 
                        purchases = 56, )
                    ],
                total_products = 56
            )
        else:
            return ReportingProductPerformanceData(
        )
        """

    def testReportingProductPerformanceData(self):
        """Test ReportingProductPerformanceData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_purchase_timing_data import ReportingPurchaseTimingData

class TestReportingPurchaseTimingData(unittest.TestCase):
    """ReportingPurchaseTimingData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPurchaseTimingData:
        """Test ReportingPurchaseTimingData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPurchaseTimingData`
        """
        model = ReportingPurchaseTimingData()
        if include_optional:
            return ReportingPurchaseTimingData(
                peak_shopping_time = '',
                timing_distribution = [
                    neurograph.v1.models.reporting/timing_bucket.reporting.TimingBucket(
                        is_peak = True, 
                        order_count = 56, 
                        percentage = 1.337, 
                        timing_bucket = '', )
                    ]
            )
        else:
            return ReportingPurchaseTimingData(
        )
        """

    def testReportingPurchaseTimingData(self):
        """Test ReportingPurchaseTimingData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_prediction_detail_response import ReportingPredictionDetailResponse

class TestReportingPredictionDetailResponse(unittest.TestCase):
    """ReportingPredictionDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPredictionDetailResponse:
        """Test ReportingPredictionDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPredictionDetailResponse`
        """
        model = ReportingPredictionDetailResponse()
        if include_optional:
            return ReportingPredictionDetailResponse(
                cached = True,
                error = '',
                prediction = neurograph.v1.models.reporting/prediction_detail.reporting.PredictionDetail(
                    account_id = '', 
                    assignment_date = '', 
                    client_id = '', 
                    persona_id = '', 
                    persona_name = '', 
                    prediction_id = '', 
                    raw_document = { }, ),
                query_time_ms = 56
            )
        else:
            return ReportingPredictionDetailResponse(
        )
        """

    def testReportingPredictionDetailResponse(self):
        """Test ReportingPredictionDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_affinity_meta import ReportingAffinityMeta

class TestReportingAffinityMeta(unittest.TestCase):
    """ReportingAffinityMeta unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingAffinityMeta:
        """Test ReportingAffinityMeta
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingAffinityMeta`
        """
        model = ReportingAffinityMeta()
        if include_optional:
            return ReportingAffinityMeta(
                client_partition_key = '',
                client_uid = '',
                data_date = '',
                generated_at = '',
                organization_uid = '',
                persona_id = ''
            )
        else:
            return ReportingAffinityMeta(
        )
        """

    def testReportingAffinityMeta(self):
        """Test ReportingAffinityMeta"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.signal_daily_purchase_metrics import SignalDailyPurchaseMetrics

class TestSignalDailyPurchaseMetrics(unittest.TestCase):
    """SignalDailyPurchaseMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SignalDailyPurchaseMetrics:
        """Test SignalDailyPurchaseMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SignalDailyPurchaseMetrics`
        """
        model = SignalDailyPurchaseMetrics()
        if include_optional:
            return SignalDailyPurchaseMetrics(
                api_success_count = 56,
                api_success_rate = 1.337,
                avg_data_completeness = 1.337,
                avg_order_value = 1.337,
                var_date = '',
                new_customers = 56,
                predicted_revenue = 1.337,
                returning_customers = 56,
                total_purchases = 56,
                total_revenue = 1.337
            )
        else:
            return SignalDailyPurchaseMetrics(
        )
        """

    def testSignalDailyPurchaseMetrics(self):
        """Test SignalDailyPurchaseMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
